Author: bugman
Date: Mon Mar  2 17:24:08 2015
New Revision: 27730

URL: http://svn.gna.org/viewcvs/relax?rev=27730&view=rev
Log:
Some more fixes for the Rdc.test_rdc_copy_different_spins system test.

The residue.delete and not spin.delete user function is required to delete the 
sequence data.


Modified:
    trunk/test_suite/system_tests/rdc.py

Modified: trunk/test_suite/system_tests/rdc.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/system_tests/rdc.py?rev=27730&r1=27729&r2=27730&view=diff
==============================================================================
--- trunk/test_suite/system_tests/rdc.py        (original)
+++ trunk/test_suite/system_tests/rdc.py        Mon Mar  2 17:24:08 2015
@@ -84,7 +84,7 @@
 
         # Set up two data identical pipes.
         pipes = ['orig', 'new']
-        delete = [':6@N', ':11@N']
+        delete = [':6', ':11']
         for i in range(2):
             # Create a data pipe.
             self.interpreter.pipe.create(pipes[i], 'N-state')
@@ -92,8 +92,8 @@
             # Load the spins.
             self.interpreter.sequence.read(file='tb.txt', dir=dir, 
spin_id_col=1)
 
-            # Delete the spin.
-            self.interpreter.spin.delete(spin_id=delete[i])
+            # Delete the residue.
+            self.interpreter.residue.delete(delete[i])
 
             # Attach protons.
             self.interpreter.sequence.attach_protons()


_______________________________________________
relax (http://www.nmr-relax.com)

This is the relax-commits mailing list
[email protected]

To unsubscribe from this list, get a password
reminder, or change your subscription options,
visit the list information page at
https://mail.gna.org/listinfo/relax-commits

Reply via email to